==> netbeans_6.7.1.orig.tar.gz: netbeans-6.7.1/bugtracking/src/org/netbeans/modules/bugtracking/ui/selectors/RepositorySelector.java <==
package org.netbeans.modules.bugtracking.ui.selectors;

/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */



import java.io.IOException;
import java.util.logging.Level;
import org.netbeans.modules.bugtracking.BugtrackingManager;
import org.netbeans.modules.bugtracking.spi.BugtrackingConnector;
import org.netbeans.modules.bugtracking.spi.Repository;

/**
 *
 * @author Tomas Stupka
 */
public class RepositorySelector {

    private SelectorPanel selectorPanel = new SelectorPanel();
    public RepositorySelector() {
        // init connector cbo
    }

    public Repository create() {
        BugtrackingConnector[] connectors = BugtrackingManager.getInstance().getConnectors();
        selectorPanel.setConnectors(connectors);
        if(!selectorPanel.open()) return null;
        Repository repo = selectorPanel.getRepository();
        try {
            repo.getController().applyChanges();
        } catch (IOException ex) {
            BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
            return null;
        }
        BugtrackingManager.getInstance().fireRepositoriesChanged();
        return repo;
    }

    public boolean edit(Repository repository, String errorMessage) {
        if(!selectorPanel.edit(repository, errorMessage)) return false;
        Repository repo = selectorPanel.getRepository();
        try {
            repo.getController().applyChanges();
        } catch (IOException ex) {
            BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
            return false;
        }
        return true;
    }

}

==> netbeans_6.8.orig.tar.gz: netbeans-6.8/bugtracking/src/org/netbeans/modules/bugtracking/ui/selectors/RepositorySelector.java <==
package org.netbeans.modules.bugtracking.ui.selectors;

/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */



import java.io.IOException;
import java.util.logging.Level;
import org.netbeans.modules.bugtracking.BugtrackingManager;
import org.netbeans.modules.bugtracking.RepositoriesSupport;
import org.netbeans.modules.bugtracking.jira.JiraUpdater;
import org.netbeans.modules.bugtracking.spi.BugtrackingConnector;
import org.netbeans.modules.bugtracking.spi.Repository;

/**
 *
 * @author Tomas Stupka
 */
public class RepositorySelector {

    private SelectorPanel selectorPanel = new SelectorPanel();
    public RepositorySelector() {
        // init connector cbo
    }

    public Repository create() {
        BugtrackingConnector[] connectors = BugtrackingManager.getInstance().getConnectors();
        connectors = addJiraProxyIfNeeded(connectors);
        selectorPanel.setConnectors(connectors);
        if(!selectorPanel.open()) {
            return null;
        }
        Repository repo = selectorPanel.getRepository();
        try {
            repo.getController().applyChanges();
        } catch (IOException ex) {
            BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
            return null;
        }
        RepositoriesSupport.getInstance().fireRepositoriesChanged();
        return repo;
    }

    public boolean edit(Repository repository, String errorMessage) {
        if(!selectorPanel.edit(repository, errorMessage)) {
            return false;
        }
        Repository repo = selectorPanel.getRepository();
        try {
            repo.getController().applyChanges();
        } catch (IOException ex) {
            BugtrackingManager.LOG.log(Level.SEVERE, null, ex);
            return false;
        }
        return true;
    }

    private BugtrackingConnector[] addJiraProxyIfNeeded(BugtrackingConnector[] connectors) {
        if(!JiraUpdater.isJiraInstalled()) {
            BugtrackingConnector[] ret = new BugtrackingConnector[connectors.length + 1];
            System.arraycopy(connectors, 0, ret, 0, connectors.length);
            ret[ret.length - 1] = JiraUpdater.getInstance().getConnector();
            connectors = ret;
        }
        return connectors;
    }

}
